@@ -17,7 +17,7 @@
 """Python bindings for Subversion."""
 
 __author__ = "Jelmer Vernooij <jelmer@samba.org>"
-__version__ = (0, 8, 9)
+__version__ = (0, 8, 10)
 
 NODE_DIR = 2
 NODE_FILE = 1
@@ -48,7 +48,7 @@ ERR_FS_NOT_DIRECTORY = 160016
 ERR_FS_NOT_FOUND = 160013
 ERR_FS_ALREADY_EXISTS = 160020
 ERR_RA_SVN_REPOS_NOT_FOUND = 210005
-ERR_WC_NOT_DIRECTORY = 155007
+ERR_WC_NOT_WORKING_COPY = ERR_WC_NOT_DIRECTORY = 155007
 ERR_ENTRY_EXISTS = 150002
 ERR_WC_PATH_NOT_FOUND = 155010
 ERR_CANCELLED = 200015
