@@ -54,19 +54,22 @@ static void log_iter_dealloc(PyObject *self)
 	}
 	Py_XDECREF(iter->exc_type);
 	Py_XDECREF(iter->exc_val);
-	Py_DECREF(iter->ra);
 	apr_pool_destroy(iter->pool);
+	Py_DECREF(iter->ra);
+	PyObject_Del(iter);
 }
 
 static PyObject *log_iter_next(LogIteratorObject *iter)
 {
 	struct log_entry *first;
 	PyObject *ret;
+	Py_INCREF(iter);
 
 	while (iter->head == NULL) {
 		/* Done, raise exception */
 		if (iter->exc_type != NULL) {
 			PyErr_SetObject(iter->exc_type, iter->exc_val);
+			Py_DECREF(iter);
 			return NULL;
 		} else {
 			Py_BEGIN_ALLOW_THREADS
@@ -81,6 +84,7 @@ static PyObject *log_iter_next(LogIteratorObject *iter)
 		iter->tail = NULL;
 	free(first);
 	iter->queue_size--;
+	Py_DECREF(iter);
 	return ret;
 }
 
@@ -298,17 +302,18 @@ static void py_iter_log(void *baton)
 			iter, iter->pool);
 #endif
 	state = PyGILState_Ensure();
-	iter->done = TRUE;
-	iter->ra->busy = false;
 	if (error != NULL) {
 		iter->exc_type = (PyObject *)PyErr_GetSubversionExceptionTypeObject();
 		iter->exc_val  = PyErr_NewSubversionException(error);
+		svn_error_clear(error);
 	} else {
 		iter->exc_type = PyExc_StopIteration;
 		Py_INCREF(iter->exc_type);
 		iter->exc_val = Py_None;
 		Py_INCREF(iter->exc_val);
 	}
+	iter->done = TRUE;
+	iter->ra->busy = false;
 
 	Py_DECREF(iter);
 	PyGILState_Release(state);
@@ -325,7 +330,7 @@ PyObject *ra_iter_log(PyObject *self, PyObject *args, PyObject *kwargs)
 	RemoteAccessObject *ra = (RemoteAccessObject *)self;
 	PyObject *revprops = Py_None;
 	LogIteratorObject *ret;
-	apr_pool_t *temp_pool;
+	apr_pool_t *pool;
 	apr_array_header_t *apr_paths;
 	apr_array_header_t *apr_revprops;
 
@@ -338,27 +343,28 @@ PyObject *ra_iter_log(PyObject *self, PyObject *args, PyObject *kwargs)
 	if (ra_check_busy(ra))
 		return NULL;
 
-	temp_pool = Pool(NULL);
-	if (temp_pool == NULL)
+	pool = Pool(ra->pool);
+	if (pool == NULL)
 		return NULL;
 	if (paths == Py_None) {
 		/* The subversion libraries don't behave as expected, 
 		 * so tweak our own parameters a bit. */
-		apr_paths = apr_array_make(temp_pool, 1, sizeof(char *));
-		APR_ARRAY_PUSH(apr_paths, char *) = apr_pstrdup(temp_pool, "");
-	} else if (!path_list_to_apr_array(temp_pool, paths, &apr_paths)) {
-		apr_pool_destroy(temp_pool);
+		apr_paths = apr_array_make(pool, 1, sizeof(char *));
+		APR_ARRAY_PUSH(apr_paths, char *) = apr_pstrdup(pool, "");
+	} else if (!path_list_to_apr_array(pool, paths, &apr_paths)) {
+		apr_pool_destroy(pool);
 		return NULL;
 	}
 
 #if ONLY_BEFORE_SVN(1, 5)
 	if (revprops == Py_None) {
-		PyErr_SetString(PyExc_NotImplementedError, "fetching all revision properties not supported");	
-		apr_pool_destroy(temp_pool);
+		PyErr_SetString(PyExc_NotImplementedError,
+		"fetching all revision properties not supported");
+		apr_pool_destroy(pool);
 		return NULL;
 	} else if (!PySequence_Check(revprops)) {
 		PyErr_SetString(PyExc_TypeError, "revprops should be a sequence");
-		apr_pool_destroy(temp_pool);
+		apr_pool_destroy(pool);
 		return NULL;
 	} else {
 		int i;
@@ -369,7 +375,7 @@ PyObject *ra_iter_log(PyObject *self, PyObject *args, PyObject *kwargs)
 				strcmp(SVN_PROP_REVISION_DATE, n)) {
 				PyErr_SetString(PyExc_NotImplementedError,
 								"fetching custom revision properties not supported");
-				apr_pool_destroy(temp_pool);
+				apr_pool_destroy(pool);
 				return NULL;
 			}
 		}
@@ -378,13 +384,13 @@ PyObject *ra_iter_log(PyObject *self, PyObject *args, PyObject *kwargs)
 	if (include_merged_revisions) {
 		PyErr_SetString(PyExc_NotImplementedError, 
 			"include_merged_revisions not supported in Subversion 1.4");
-		apr_pool_destroy(temp_pool);
+		apr_pool_destroy(pool);
 		return NULL;
 	}
 #endif
 
-	if (!string_list_to_apr_array(temp_pool, revprops, &apr_revprops)) {
-		apr_pool_destroy(temp_pool);
+	if (!string_list_to_apr_array(pool, revprops, &apr_revprops)) {
+		apr_pool_destroy(pool);
 		return NULL;
 	}
 
@@ -398,7 +404,7 @@ PyObject *ra_iter_log(PyObject *self, PyObject *args, PyObject *kwargs)
 	ret->end = end;
 	ret->limit = limit;
 	ret->apr_paths = apr_paths;
-	ret->pool = temp_pool;
+	ret->pool = pool;
 	ret->include_merged_revisions = include_merged_revisions;
 	ret->strict_node_history = strict_node_history;
 	ret->apr_revprops = apr_revprops;
