@@ -25,6 +25,13 @@ import shutil
 import sys
 import tempfile
 import unittest
+try:
+    from unittest import SkipTest
+except ImportError:
+    try:
+        from unittest2 import SkipTest
+    except ImportError:
+        from testtools.testcase import TestSkipped as SkipTest
 import urllib2
 import urlparse
 
@@ -41,24 +48,18 @@ from subvertpy.ra import (
     )
 
 
-class TestCaseInTempDir(unittest.TestCase):
+class TestCase(unittest.TestCase):
+    """Base test case.
 
-    def setUp(self):
-        unittest.TestCase.setUp(self)
-        self._oldcwd = os.getcwd()
-        self.test_dir = tempfile.mkdtemp()
-        os.chdir(self.test_dir)
+    :note: Adds assertIsInstance and assertIs.
+    """
 
-    def tearDown(self):
-        unittest.TestCase.tearDown(self)
-        os.chdir(self._oldcwd)
-        shutil.rmtree(self.test_dir)
-
-    def assertIsInstance(self, obj, kls):
+    def assertIsInstance(self, obj, kls, msg=None):
         """Fail if obj is not an instance of kls"""
         if not isinstance(obj, kls):
-            self.fail("%r is an instance of %s rather than %s" % (
-                obj, obj.__class__, kls))
+            if msg is None: msg = "%r is an instance of %s rather than %s" % (
+                obj, obj.__class__, kls)
+            self.fail(msg)
 
     def assertIs(self, left, right, message=None):
         if not (left is right):
@@ -68,8 +69,24 @@ class TestCaseInTempDir(unittest.TestCase):
                 raise AssertionError("%r is not %r." % (left, right))
 
 
+class TestCaseInTempDir(TestCase):
+    """Test case that runs in a temporary directory."""
+
+    def setUp(self):
+        TestCase.setUp(self)
+        self._oldcwd = os.getcwd()
+        self.test_dir = tempfile.mkdtemp()
+        os.chdir(self.test_dir)
+
+    def tearDown(self):
+        TestCase.tearDown(self)
+        os.chdir(self._oldcwd)
+        shutil.rmtree(self.test_dir)
+
 
 class TestFileEditor(object):
+    """Simple file editor wrapper that doesn't require closing."""
+
     def __init__(self, file):
         self.file = file
         self.is_closed = False
@@ -90,6 +107,7 @@ class TestFileEditor(object):
 
 
 class TestDirEditor(object):
+    """Simple dir editor wrapper that doesn't require closing."""
 
     def __init__(self, dir, baseurl, revnum):
         self.dir = dir
@@ -110,6 +128,7 @@ class TestDirEditor(object):
         self.dir.close()
 
     def change_prop(self, name, value):
+        self.close_children()
         self.dir.change_prop(name, value)
 
     def open_dir(self, path):
@@ -132,7 +151,8 @@ class TestDirEditor(object):
             copyfrom_rev = self.revnum
         assert (copyfrom_path is None and copyfrom_rev == -1) or \
                (copyfrom_path is not None and copyfrom_rev > -1)
-        child = TestDirEditor(self.dir.add_directory(path, copyfrom_path, copyfrom_rev), self.baseurl, self.revnum)
+        child = TestDirEditor(self.dir.add_directory(path, copyfrom_path,
+            copyfrom_rev), self.baseurl, self.revnum)
         self.children.append(child)
         return child
 
@@ -142,15 +162,18 @@ class TestDirEditor(object):
             copyfrom_path = urlparse.urljoin(self.baseurl+"/", copyfrom_path)
         if copyfrom_path is not None and copyfrom_rev == -1:
             copyfrom_rev = self.revnum
-        child = TestFileEditor(self.dir.add_file(path, copyfrom_path, copyfrom_rev))
+        child = TestFileEditor(self.dir.add_file(path, copyfrom_path,
+            copyfrom_rev))
         self.children.append(child)
         return child
 
     def delete(self, path):
+        self.close_children()
         self.dir.delete_entry(path)
 
 
 class TestCommitEditor(TestDirEditor):
+    """Simple commit editor wrapper."""
 
     def __init__(self, editor, baseurl, revnum):
         self.editor = editor
@@ -162,13 +185,12 @@ class TestCommitEditor(TestDirEditor):
 
 
 class SubversionTestCase(TestCaseInTempDir):
-    """A test case that provides the ability to build Subversion 
+    """A test case that provides the ability to build Subversion
     repositories."""
 
-    def setUp(self):
-        super(SubversionTestCase, self).setUp()
+    def _init_client(self):
         self.client_ctx = client.Client()
-        self.client_ctx.auth = Auth([ra.get_simple_provider(), 
+        self.client_ctx.auth = Auth([ra.get_simple_provider(),
                                      ra.get_username_provider(),
                                      ra.get_ssl_client_cert_file_provider(),
                                      ra.get_ssl_client_cert_pw_file_provider(),
@@ -176,6 +198,14 @@ class SubversionTestCase(TestCaseInTempDir):
         self.client_ctx.log_msg_func = self.log_message_func
         #self.client_ctx.notify_func = lambda err: mutter("Error: %s" % err)
 
+    def setUp(self):
+        super(SubversionTestCase, self).setUp()
+        self._init_client()
+
+    def tearDown(self):
+        del self.client_ctx
+        super(SubversionTestCase, self).tearDown()
+
     def log_message_func(self, items):
         return self.next_message
 
@@ -190,10 +220,12 @@ class SubversionTestCase(TestCaseInTempDir):
 
         if allow_revprop_changes:
             if sys.platform == 'win32':
-                revprop_hook = os.path.join(abspath, "hooks", "pre-revprop-change.bat")
+                revprop_hook = os.path.join(abspath, "hooks",
+                        "pre-revprop-change.bat")
                 open(revprop_hook, 'w').write("exit 0\n")
             else:
-                revprop_hook = os.path.join(abspath, "hooks", "pre-revprop-change")
+                revprop_hook = os.path.join(abspath, "hooks",
+                        "pre-revprop-change")
                 open(revprop_hook, 'w').write("#!/bin/sh\n")
                 os.chmod(revprop_hook, os.stat(revprop_hook).st_mode | 0111)
 
@@ -204,14 +236,17 @@ class SubversionTestCase(TestCaseInTempDir):
 
 
     def make_checkout(self, repos_url, relpath):
-        self.client_ctx.checkout(repos_url, relpath, "HEAD") 
+        """Create a new checkout."""
+        self.client_ctx.checkout(repos_url, relpath, "HEAD")
 
     def client_set_prop(self, path, name, value):
+        """Set a property on a local file or directory."""
         if value is None:
             value = ""
         self.client_ctx.propset(name, value, path, False, True)
 
     def client_get_prop(self, path, name, revnum=None, recursive=False):
+        """Retrieve a property from a local or remote file or directory."""
         if revnum is None:
             rev = "WORKING"
         else:
@@ -234,15 +269,23 @@ class SubversionTestCase(TestCaseInTempDir):
         return r.rev_proplist(revnum)[name]
 
     def client_set_revprop(self, url, revnum, name, value):
+        """Set a revision property on a repository.
+
+        :param url: URL of the repository
+        :param revnum: Revision number of the revision
+        :param name: Name of the property
+        :param value: Value of the property, None to remove
+        """
         r = ra.RemoteAccess(url, auth=Auth([ra.get_username_provider()]))
         r.change_rev_prop(revnum, name, value)
 
     def client_resolve(self, path, choice, depth=0):
+        """Resolve a conflict set on a local path."""
         self.client_ctx.resolve(path, depth, choice)
-        
+
     def client_commit(self, dir, message=None, recursive=True):
         """Commit current changes in specified working copy.
-        
+
         :param dir: List of paths to commit.
         """
         olddir = os.path.abspath('.')
@@ -255,7 +298,7 @@ class SubversionTestCase(TestCaseInTempDir):
 
     def client_add(self, relpath, recursive=True):
         """Add specified files to working copy.
-        
+
         :param relpath: Path to the files to add.
         """
         self.client_ctx.add(relpath, recursive, False, False)
@@ -272,9 +315,14 @@ class SubversionTestCase(TestCaseInTempDir):
         assert isinstance(url, str)
         ret = {}
         def rcvr(orig_paths, rev, revprops, has_children=None):
-            ret[rev] = (orig_paths, revprops.get(properties.PROP_REVISION_AUTHOR), revprops.get(properties.PROP_REVISION_DATE), revprops.get(properties.PROP_REVISION_LOG))
-        r.get_log(rcvr, [""], start_revnum, stop_revnum, 0, True, True, 
-                  revprops=[properties.PROP_REVISION_AUTHOR, properties.PROP_REVISION_DATE, properties.PROP_REVISION_LOG])
+            ret[rev] = (orig_paths,
+                    revprops.get(properties.PROP_REVISION_AUTHOR),
+                    revprops.get(properties.PROP_REVISION_DATE),
+                    revprops.get(properties.PROP_REVISION_LOG))
+        r.get_log(rcvr, [""], start_revnum, stop_revnum, 0, True, True,
+                  revprops=[properties.PROP_REVISION_AUTHOR,
+                      properties.PROP_REVISION_DATE,
+                      properties.PROP_REVISION_LOG])
         return ret
 
     def client_delete(self, relpath):
@@ -305,8 +353,8 @@ class SubversionTestCase(TestCaseInTempDir):
 
     def build_tree(self, files):
         """Create a directory tree.
-        
-        :param files: Dictionary with filenames as keys, contents as 
+
+        :param files: Dictionary with filenames as keys, contents as
             values. None as value indicates a directory.
         """
         for f in files:
@@ -325,12 +373,12 @@ class SubversionTestCase(TestCaseInTempDir):
     def make_client(self, repospath, clientpath, allow_revprop_changes=True):
         """Create a repository and a checkout. Return the checkout.
 
-        :param repospath: Optional relpath to check out if not the full 
+        :param repospath: Optional relpath to check out if not the full
             repository.
         :param clientpath: Path to checkout
         :return: Repository URL.
         """
-        repos_url = self.make_repository(repospath, 
+        repos_url = self.make_repository(repospath,
             allow_revprop_changes=allow_revprop_changes)
         self.make_checkout(repos_url, clientpath)
         return repos_url
@@ -349,7 +397,7 @@ class SubversionTestCase(TestCaseInTempDir):
         :param message: Commit message
         :return: Commit editor object
         """
-        ra_ctx = RemoteAccess(url.encode("utf-8"), 
+        ra_ctx = RemoteAccess(url.encode("utf-8"),
             auth=Auth([ra.get_username_provider()]))
         revnum = ra_ctx.get_latest_revnum()
         return TestCommitEditor(ra_ctx.get_commit_editor({"svn:log": message}),
