@@ -18,6 +18,7 @@
 from StringIO import StringIO
 import os
 
+import subvertpy
 from subvertpy import (
     NODE_FILE,
     wc,
@@ -114,7 +115,6 @@ class AdmTests(SubversionTestCase):
     def test_add_repos_file(self):
         repos_url = self.make_client("repos", "checkout")
         adm = wc.WorkingCopy(None, "checkout", True)
-        adm.add_repos_file("checkout/bar", StringIO("oldbasecontents"), StringIO("oldcontents"), {}, {})
         adm.add_repos_file("checkout/bar", StringIO("basecontents"), StringIO("contents"), {}, {})
         self.assertEquals("basecontents", wc.get_pristine_contents("checkout/bar").read())
 
@@ -173,6 +173,16 @@ class AdmTests(SubversionTestCase):
         adm.prop_set("aprop", "avalue", "checkout/bar")
         self.assertTrue(adm.props_modified("checkout/bar"))
 
+    def test_prop_set(self):
+        repos_url = self.make_client("repos", "checkout")
+        self.build_tree({"checkout/bar": "file"})
+        self.client_add('checkout/bar')
+        adm = wc.WorkingCopy(None, "checkout", True)
+        adm.prop_set("aprop", "avalue", "checkout/bar")
+        self.assertEquals(adm.prop_get("aprop", "checkout/bar"), "avalue")
+        adm.prop_set("aprop", None, "checkout/bar")
+        self.assertEquals(adm.prop_get("aprop", "checkout/bar"), None)
+
     def test_committed_queue(self):
         if getattr(wc, "CommittedQueue", None) is None:
             raise SkipTest("CommittedQueue not available")
@@ -270,7 +280,7 @@ class AdmTests(SubversionTestCase):
         self.client_add('checkout/bar')
         adm = wc.WorkingCopy(None, "checkout", True)
         cq = wc.CommittedQueue()
-        cq.queue("bar", adm)
+        cq.queue(os.path.join(self.test_dir, "checkout/bar"), adm)
         adm.process_committed_queue(cq, 1, "2010-05-31T08:49:22.430000Z", "jelmer")
         bar = adm.entry("checkout/bar")
         self.assertEquals("bar", bar.name)
@@ -282,5 +292,9 @@ class AdmTests(SubversionTestCase):
         self.build_tree({"checkout/bar": "la"})
         self.client_add('checkout/bar')
         adm = wc.WorkingCopy(None, "checkout", True)
-        self.assertIs(None, adm.probe_try(self.test_dir))
+        try:
+            self.assertIs(None, adm.probe_try(self.test_dir))
+        except subvertpy.SubversionException, (msg, num):
+            if num != subvertpy.ERR_WC_NOT_WORKING_COPY:
+                raise
         self.assertEquals("checkout", adm.probe_try(os.path.join("checkout", "bar")).access_path())
